# CODEIt
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-3-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

![Python](https://img.shields.io/badge/Language-Python-blue?style=flat-square&logo=python) [![Docker](https://img.shields.io/badge/-Docker%20Hub-blue?style=flat-square&logo=docker)](https://hub.docker.com/repository/docker/aerox86/codeit) [![PyPI](https://img.shields.io/badge/-PyPI%20Official-green?style=flat-square&logo=python)](https://pypi.org/project/cxit)
[![Build](https://github.com/Arch2x/codeit/workflows/Python%20package/badge.svg)](https://github.com/Arch2x/codeit/actions/workflows/python-package.yml) [![CodeQL](https://github.com/Arch2x/codeit/workflows/CodeQL/badge.svg)](https://github.com/Arch2x/codeit/actions/workflows/codeql-analysis.yml) [![Upload](https://github.com/Arch2x/codeit/workflows/Upload%20Python%20Package/badge.svg)](https://github.com/Arch2x/codeit/actions/workflows/python-publish.yml)
[![Travis CI Build Status](https://travis-ci.com/Arch2x/codeit.svg?branch=master)](https://travis-ci.com/Arch2x/codeit)

### A CLI based Script tool to create CPP files for programming contests

In times of contests, one has to create a CPP file, type code in it, test the cases, find the errors etc. Some times, it'd be really hectic to create files and start. But how about a tool to generate a directory which has all the files you need?? ;)

#### CODEIt eases this problem by creating the directory which has all files in it

**C++ template is only added for now, more to come in future!**

## Installation (for users)
- Make sure you've installed Python 3 in you system, if not do it first.
- Then type the following commands...
  - `pip install clint`
  - `pip install watchdog`
- Then finally type `pip install cxit` (package is still codeit but renamed to avoid conflicts)
- Type `codeit` and you're good to go!

## Installation (for developers)
- To install type `git clone https://github.com/Arch2x/codeit` to clone the repo into your system
- Next, go to the folder by using the `cd` command or directly use `bash` or `cmd` on the file path of repo
- Then type `pip install setuptools`
- Finally, type `pip install .`
- Wait for sometime until the script finishes installing necessary packages
- Then, voila! Type `codeit` to start!   

![Demo](https://raw.githubusercontent.com/alphaX86/codeit/master/code.gif)

## Demo
Here's a demo of the project to understand! (Done using VS Code)

![Demo1](https://raw.githubusercontent.com/alphaX86/codeit/master/Demo.gif)


## Contributions
Any type of contributions are welcome for this repo! Refer [Contributions](./CONTRIBUTING.md) to know how to contribute to this repo and more. 

## Code Of Conduct
This repo follows the [Contributor Covenant](./CODE_OF_CONDUCT.md) to enforce proper behaviour. Refer the doc for more details.

## Maintainers ✨👨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://alphax86.github.io"><img src="https://avatars1.githubusercontent.com/u/59508546?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Aadhitya A</b></sub></a><br /><a href="https://github.com/Arch2x/codeit/commits?author=alphaX86" title="Code">💻</a> <a href="#design-alphaX86" title="Design">🎨</a> <a href="https://github.com/Arch2x/codeit/commits?author=alphaX86" title="Documentation">📖</a> <a href="#mentoring-alphaX86" title="Mentoring">🧑‍🏫</a> <a href="#maintenance-alphaX86" title="Maintenance">🚧</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->


## Contributors ✨
<a href="https://github.com/Arch2x/codeit/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=Arch2x/codeit" />
</a>


Thanks a lot guys! 

## Stargazers over time

[![Stargazers over time](https://starchart.cc/Arch2x/codeit.svg)](https://starchart.cc/Arch2x/codeit)

With your effort, we can raise the numbers! ;) 

## License 
This project uses [MIT License](https://opensource.org/licenses/MIT) to maintain integrity

